@@ -32,8 +32,14 @@ pub fn network(interface: Option<&str>) -> Result<String, ReadoutError> {
     let readout = NetworkReadout::new();
 
     fmt.set_logical_address(readout.logical_address(interface)?);
-    fmt.set_rx_bytes(readout.rx_bytes(interface)?);
-    fmt.set_tx_bytes(readout.tx_bytes(interface)?);
+
+    if let Ok(rx_bytes) = readout.rx_bytes(interface) {
+        fmt.set_rx_bytes(rx_bytes);
+    }
+
+    if let Ok(tx_bytes) = readout.tx_bytes(interface) {
+        fmt.set_tx_bytes(tx_bytes);
+    }
 
     Ok(fmt.to_string())
 }
